Subject: [PATCH wq#for-2.6.39] workqueue: fix build failure introduced by s/freezeable/freezable/

From: Tejun Heo <[email-masked]>
Date: Mon, 21 Feb 2011 10:03:54 +0100

new usage of the flag.  The combination of the two creates a build
failure after merge.  Fix it by renaming all freezeables to
freezables.

Signed-off-by: Tejun Heo <[email-masked]>
Reported-by: Stephen Rothwell <[email-masked]>
---
I pulled mainline into wq#for-2.6.39 and applied the build fix.
#for-next updated accordingly.  Dmitry, please feel free to pull in
the following branch for system_wq_freezable.  The branch is stable.
HEAD is 6c9e293a1f (workqueue: fix build failure introduced by
s/freezeable/freezable/).

 git://git.kernel.org/pub/scm/linux/kernel/git/tj/wq.git for-2.6.39

Thank you.

 include/linux/workqueue.h |    6 +++---
 kernel/workqueue.c        |   10 +++++-----
 2 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/kernel/workqueue.c b/kernel/workqueue.c
index 572f559..1b64d22 100644
--- a/kernel/workqueue.c
+++ b/kernel/workqueue.c
@@ -251,12 +251,12 @@ struct workqueue_struct *system_wq __read_mostly;
 struct workqueue_struct *system_long_wq __read_mostly;
 struct workqueue_struct *system_nrt_wq __read_mostly;
 struct workqueue_struct *system_unbound_wq __read_mostly;
-struct workqueue_struct *system_freezeable_wq __read_mostly;
+struct workqueue_struct *system_freezable_wq __read_mostly;
 EXPORT_SYMBOL_GPL(system_wq);
 EXPORT_SYMBOL_GPL(system_long_wq);
 EXPORT_SYMBOL_GPL(system_nrt_wq);
 EXPORT_SYMBOL_GPL(system_unbound_wq);
-EXPORT_SYMBOL_GPL(system_freezeable_wq);
+EXPORT_SYMBOL_GPL(system_freezable_wq);
 
 #define CREATE_TRACE_POINTS
 #include <trace/events/workqueue.h>
@@ -3777,10 +3777,10 @@ static int __init init_workqueues(void)
 	system_nrt_wq = alloc_workqueue("events_nrt", WQ_NON_REENTRANT, 0);
 	system_unbound_wq = alloc_workqueue("events_unbound", WQ_UNBOUND,
 					    WQ_UNBOUND_MAX_ACTIVE);
-	system_freezeable_wq = alloc_workqueue("events_freezeable",
-					       WQ_FREEZEABLE, 0);
+	system_freezable_wq = alloc_workqueue("events_freezable",
+					      WQ_FREEZABLE, 0);
 	BUG_ON(!system_wq || !system_long_wq || !system_nrt_wq ||
-	       !system_unbound_wq || !system_freezeable_wq);
+	       !system_unbound_wq || !system_freezable_wq);
 	return 0;
 }
 early_initcall(init_workqueues);
diff --git a/include/linux/workqueue.h b/include/linux/workqueue.h
index d110cc4..f584aba 100644
--- a/include/linux/workqueue.h
+++ b/include/linux/workqueue.h
@@ -287,14 +287,14 @@ enum {
  * executed immediately as long as max_active limit is not reached and
  * resources are available.
  *
  * system_freezeable_wq is equivalent to system_wq except that it's
  * freezeable.
  */
 extern struct workqueue_struct *system_wq;
 extern struct workqueue_struct *system_long_wq;
 extern struct workqueue_struct *system_nrt_wq;
 extern struct workqueue_struct *system_unbound_wq;
-extern struct workqueue_struct *system_freezeable_wq;
+extern struct workqueue_struct *system_freezable_wq;
 
 extern struct workqueue_struct *
 __alloc_workqueue_key(const char *name, unsigned int flags, int max_active,
@@ -287,14 +287,14 @@ enum {
  * resources are available.
  *
- * system_freezeable_wq is equivalent to system_wq except that it's
- * freezeable.
+ * system_freezable_wq is equivalent to system_wq except that it's
+ * freezable.
  */
 extern struct workqueue_struct *system_wq;
-- 
1.7.1